@@ -6,10 +6,10 @@ QECore __init__ file.
 from __future__ import absolute_import, division, print_function, unicode_literals
 
 __author__ = """Michal Odehnal <modehnal@redhat.com>"""
-__version__ = "3.17"
-__copyright__ = "Copyright © 2018-2023 Red Hat, Inc."
-__license__ = "GPL"
+__copyright__ = "Copyright © 2018-2024 Red Hat, Inc."
+__license__ = "GPLv3"
 __all__ = (
+    "api",
     "application",
     "common_steps",
     "flatpak",
