@@ -3,13 +3,21 @@
 Flatpak class to be used from TestSandbox to keep list of running applications.
 """
 
+__author__ = """
+Martin Krajnak <mkrajnak@redhat.com>
+"""
+
 from os import walk, path
 import configparser
 
-from qecore.utility import run
+from qecore.utility import run, get_func_params_and_values
+
 from qecore.application import Application
 
-__author__ = """Martin Krajnak <mkrajnak@redhat.com>"""
+from qecore.logger import Logging
+
+logging_class = Logging()
+LOGGING = logging_class.logger
 
 
 class Flatpak(Application):
@@ -26,11 +34,13 @@ class Flatpak(Application):
 
         :type flatpak_id: str
         :param flatpak_id: Unique flatpak identifier, mandatory format has 2 dots.
-            Param is passed to Application contructor as .component
+            Param is passed to Application constructor as .component
 
         :param kwargs: :py:class:`application.Application` parameters.
         """
 
+        LOGGING.debug(get_func_params_and_values())
+
         if flatpak_id.count(".") != 2:
             raise UserWarning(
                 f"Incorrect flatpak name {flatpak_id}, e.g.: 'org.gnome.gedit'."
@@ -43,6 +53,8 @@ class Flatpak(Application):
         Killing via 'flatpak kill <flatpak_id>', sudo for @system flatpaks.
         """
 
+        LOGGING.debug(get_func_params_and_values())
+
         if self.is_running() and self.kill:
             # Kills a flatpak installed @System.
             run(f"sudo flatpak kill {self.component}")
@@ -56,7 +68,7 @@ class Flatpak(Application):
 
                 ~/.local/share/flatpak/app/<flatpak_id>/<arch>/....
 
-            * flatpak instaled as *@system* (sudo, root)::
+            * flatpak installed as *@system* (sudo, root)::
 
                 /var/lib/flatpak/app/<flatpak_id>/<arch>/.....
 
@@ -65,6 +77,8 @@ class Flatpak(Application):
             Do **NOT** call this by yourself. This method is called by :func:`__init__`.
         """
 
+        LOGGING.debug(get_func_params_and_values())
+
         def get_desktop_file_path(flatpak_dir) -> None:
             """
             Helper function used for dynamic search of desktop files as
@@ -106,7 +120,14 @@ class Flatpak(Application):
         Double check if running application is really a flatpak.
         """
 
-        return super().is_running() and (self.component in run("flatpak ps"))
+        LOGGING.debug(get_func_params_and_values())
+
+        flatpak_is_running = self.component in run("flatpak ps")
+
+        if not flatpak_is_running:
+            LOGGING.debug(f"Flatpak '{self.name}' is not running.")
+
+        return super().is_running() and flatpak_is_running
 
     def start_via_menu(self, kill=False) -> None:
         """
@@ -119,11 +140,13 @@ class Flatpak(Application):
             Make sure that the .rpm version of a tested flatpak is not installed.
         """
 
+        LOGGING.debug(get_func_params_and_values())
+
         rpms = run(f'rpm -qa | grep -i "{self.name}"')
         if rpms:
             print(
                 f"WARNING: a method could possibly start a non-flatpak application\n"
-                f"{self.name} is already instaled as .rpm: {rpms}"
+                f"{self.name} is already installed as .rpm: {rpms}"
             )
 
         super().start_via_menu(kill)
@@ -137,6 +160,8 @@ class Flatpak(Application):
             This method is not available for flatpak objects.
         """
 
+        LOGGING.debug(get_func_params_and_values())
+
         raise NotImplementedError("Not available for flatpak objects.")
 
     def get_all_kill_candidates(self) -> None:
@@ -148,4 +173,6 @@ class Flatpak(Application):
             This method is not available for flatpak objects.
         """
 
+        LOGGING.debug(get_func_params_and_values())
+
         raise NotImplementedError("Not available for flatpak objects.")
